
File copy from https://github.com/antlr/grammars-v4/blob/master/thrift/README.md

ANTLR v4 grammar for Apache Thrift interface description language (IDL): http://thrift.apache.org/docs/idl

## License
Apache License 2.0: http://www.apache.org/licenses/LICENSE-2.0.txt
